from dqc_wrapper.test06_valid_ranges import ValidRangesTest
from dqc_wrapper.unit_tests.conftest import dirs
from pathlib import Path
import xarray as xr


def test_get_stats():
    test = ValidRangesTest([dirs.nc_file], 'tas', '', '', '', 0)
    ds = xr.open_dataset(dirs.nc_file)
    # random values between 10 and 25
    min, max, mean, kurt, skew, std = test.get_stats(ds['tas'].data)
    assert min >= 10
    assert max <= 25
    assert mean >= min and mean <= max
    assert kurt.shape == (320, 160)
    assert skew.shape == (320, 160)
    assert std > 0

def test_load_datafile():
    test = ValidRangesTest([dirs.nc_file], 'tas', '', '', '', 0)
    arr = test.load_datafile(dirs.nc_file)
    assert len(arr) == 5*320*160

def test_check_valid_ranges():
    test = ValidRangesTest([dirs.nc_file], 'tas', '', '', '', 0)
    res, msg = test.check_valid_ranges()
    assert res == "ok"
    # Min and max outside range
    test = ValidRangesTest([dirs.nc_file], 'tas', 100, 200, '', 0)
    res, msg = test.check_valid_ranges()
    assert res == "err"
    # Deleting generated CSV
    Path(dirs.test_dir, "sample").unlink()